@@ -1,6 +1,6 @@
 /* -*- mode:c; coding:utf-8; tab-width:8; c-basic-offset:2; indent-tabs-mode:nil -*- */
 /*
-  Copyright (c) 2004 MacUIM Project
+  Copyright (c) 2003-2004 MacUIM contributors and others
   http://www.digital-genes.com/~yatsu/macuim/
 
   All rights reserved.
@@ -36,11 +36,13 @@
 #include "CandidateCarbon.h"
 
 
-//#define DEBUG_CANDIDATES 1
-
-
 extern uim_context gUC;
 
+extern int gCandTransparency;
+
+extern CFStringRef gCandFont;
+extern float gCandFontSize;
+
 
 static Boolean
 TrimIndex(MUIMSessionHandle inHandle);
@@ -57,6 +59,7 @@ LayoutCandidate(MUIMSessionHandle inHandle)
   TSMStat tsmStat;
   OSErr err = noErr;
 
+  // get the cursor position
   err = MUIMGetTSMStatus(inHandle, &tsmStat);
 
 #if DEBUG_CANDIDATES
@@ -84,9 +87,6 @@ InitCandidateWindow(MUIMSessionHandle inHandle)
   CFURLRef bundleURL2 = NULL;
   OSStatus (*initPtr)(void *);
 
-  //char buf[BUFSIZ];
-  //CFIndex len;
-
   if ((*inHandle)->fBundleRef) return noErr;
 
   appBundle = CFBundleGetMainBundle();
@@ -130,6 +130,8 @@ InitCandidateWindow(MUIMSessionHandle inHandle)
 
   res = (*initPtr)(HandleBundleCommand);
   require_noerr(res, CantInitializeBundle);
+  
+  SetCandidateFont(inHandle, gCandFont, gCandFontSize);
                 
  CantCreateBundleURL:
  CantCreateBundle:
@@ -148,7 +150,7 @@ ShowCandidateWindow(MUIMSessionHandle inHandle,
 {
   OSStatus res = noErr;
   UInt32 i;
-  OSStatus (*showPtr)(SInt16, SInt16, SInt16);
+  OSStatus (*showPtr)(SInt16, SInt16, SInt16, SInt16);
   OSStatus (*pagePtr)(int, int);
 
   if (!(*inHandle)->fBundleRef)
@@ -237,7 +239,8 @@ ShowCandidateWindow(MUIMSessionHandle inHandle,
   if (showPtr)
     res = (*showPtr)(inTSMStat->fReplyPoint.h,
                      inTSMStat->fReplyPoint.v,
-                     inTSMStat->fReplyLineHeight);
+                     inTSMStat->fReplyLineHeight,
+                     gCandTransparency);
 
   //(*inHandle)->fWindowOpened = true;
 
@@ -385,23 +388,31 @@ UpdateCandidate(MUIMSessionHandle inHandle)
 }
 
 OSStatus
-#if 0
-ShowModeTips(MUIMSessionHandle inHandle, CFStringRef inLabel)
-#else
+SetCandidateFont(MUIMSessionHandle inHandle, CFStringRef name, float size)
+{
+  OSStatus res = noErr;
+  OSStatus (*funcPtr)(CFStringRef, float);
+  
+  if (!(*inHandle)->fBundleRef)
+    return noErr;
+  
+  funcPtr = CFBundleGetFunctionPointerForName((*inHandle)->fBundleRef,
+                                              CFSTR("setFont"));
+  
+  if (funcPtr)
+    res = (*funcPtr)(name, size);
+  
+  return res;
+}
+
+OSStatus
 ShowModeTips(MUIMSessionHandle inHandle, CFArrayRef inLines)
-#endif
 {
   OSStatus res = noErr;
-#if 0
-  OSStatus (*showPtr)(SInt16, SInt16, SInt16, CFStringRef);
-#else
   OSStatus (*showPtr)(SInt16, SInt16, SInt16, CFArrayRef);
-#endif
   TSMStat tsmStat;
 
-  //DEBUG_PRINT("ShowModeTips() inLabel='%s'\n",
-  //            CFStringGetCStringPtr(inLabel, kCFStringEncodingUTF8));
-
+  // get the cursor position
   res = MUIMGetTSMStatus(inHandle, &tsmStat);
   
   if (!(*inHandle)->fBundleRef)
@@ -414,12 +425,7 @@ ShowModeTips(MUIMSessionHandle inHandle, CFArrayRef inLines)
     res = (*showPtr)(tsmStat.fReplyPoint.h,
                      tsmStat.fReplyPoint.v,
                      tsmStat.fReplyLineHeight,
-#if 0
-                     inLabel
-#else
-                     inLines
-#endif
-                     );
+                     inLines);
   
   return res;
 }
