@@ -1,6 +1,6 @@
 /* -*- mode:c; coding:utf-8; tab-width:8; c-basic-offset:4; indent-tabs-mode:nil -*- */
 /*
-  Copyright (c) 2004 MacUIM Project
+  Copyright (c) 2003-2004 MacUIM contributors and others
   http://www.digital-genes.com/~yatsu/macuim/
 
   All rights reserved.
@@ -53,18 +53,17 @@ ShowCandidateWindow(MUIMSessionHandle inHandle, TSMStat *inTSMStat);
 OSStatus
 HideCandidateWindow(MUIMSessionHandle inHandle);
 
-#if 0
+Boolean
+CandidateWindowIsVisible(MUIMSessionHandle inHandle);
+
 OSStatus
-ShowModeTips(MUIMSessionHandle inHandle, CFStringRef inLabel);
-#else
+SetCandidateFont(MUIMSessionHandle inHandle, CFStringRef name, float size);
+
 OSStatus
 ShowModeTips(MUIMSessionHandle inHandle, CFArrayRef inLines);
-#endif
 
 OSStatus
 HideModeTips(MUIMSessionHandle inHandle);
 
-Boolean
-CandidateWindowIsVisible(MUIMSessionHandle inHandle);
 
 #endif  /* __CANDIDATE_CARBON_H__ */
