@@ -1,6 +1,6 @@
 /* -*- mode:c; coding:utf-8; tab-width:8; c-basic-offset:2; indent-tabs-mode:nil -*- */
 /*
-  Copyright (c) 2004 MacUIM Project
+  Copyright (c) 2003-2004 MacUIM contributors and others
   http://www.digital-genes.com/~yatsu/macuim/
 
   All rights reserved.
@@ -92,13 +92,16 @@ CFRunLoopSourceRef gUimRun;
 CFSocketContext gSockContext;
 
 #ifdef SYNC_MODE
-/** current mode */
+// current mode
 SInt32 gMode = -1;
 #endif
 
 CFStringRef gIMName = NULL;
 Boolean gEnableModeTips = true;
 Boolean gCandVertical = true;
+int gCandTransparency = 0;
+CFStringRef gCandFont = NULL;
+float gCandFontSize = 0.0;
 
 static MenuRef gPencilMenu;
 
@@ -252,7 +255,26 @@ MUIMInitialize(ComponentInstance inComponentInstance,
     gCandVertical = true;
   else
     gCandVertical = false;
- 
+  
+  gCandTransparency =
+    CFPreferencesGetAppIntegerValue(CFSTR(kPrefCandTransparency),
+                                    CFSTR(kAppID), &dummy);
+  
+  // candidate font
+  {
+    CFPropertyListRef propVal;
+
+    propVal = CFPreferencesCopyAppValue(CFSTR(kPrefCandFont), CFSTR(kAppID));
+    if (propVal && CFGetTypeID(propVal) == CFStringGetTypeID()) {
+      gCandFont = (CFStringRef) propVal;
+      CFRetain(gCandFont);
+    }
+    
+    propVal = CFPreferencesCopyAppValue(CFSTR(kPrefCandFontSize), CFSTR(kAppID));
+    if (propVal && CFGetTypeID(propVal) == CFNumberGetTypeID())
+      CFNumberGetValue((CFNumberRef) propVal, kCFNumberFloatType, &gCandFontSize);
+  }
+  
   if (CFPreferencesGetAppBooleanValue(CFSTR(kPrefModeTips),
                                       CFSTR(kAppID), &dummy))
     gEnableModeTips = true;
@@ -640,6 +662,7 @@ MUIMHandleInput(MUIMSessionHandle inSessionHandle, UInt32 inKeycode,
 
   if (CandidateWindowIsVisible(inSessionHandle) &&
       inModifiers == 0 &&
+      (*inSessionHandle)->fCandidateIndex >= 0 && // PRIME - if there is no selection delegate the input event to prime.scm
       (inCharCode >= '0' && inCharCode <= '9')) {
     UInt32 row = inCharCode == '0' ? 9 : inCharCode - '1';
 #if DEBUG_KEYEVENT
@@ -653,7 +676,7 @@ MUIMHandleInput(MUIMSessionHandle inSessionHandle, UInt32 inKeycode,
       CandClicked(row);
     return TRUE;
   }
-  
+
   /* Check for special keys first */
   for (i = 0; KeycodeToUKey[i].ukey; i++) {
     if (KeycodeToUKey[i].keycode == inKeycode) {
@@ -801,7 +824,7 @@ CreateUIMContext(MUIMSessionHandle inSessionHandle, CFStringRef inIMName)
   }
 
   (*inSessionHandle)->fUC =
-    uim_create_context(inSessionHandle, /* gSessionList, */
+    uim_create_context(inSessionHandle,
                        "UTF-8", NULL, imName,
                        uim_iconv, UIMCommitString);
 
@@ -870,7 +893,11 @@ NotificationCallback(CFNotificationCenterRef inCenter, void *inObserver,
 {
   CFStringRef im;
   CFBooleanRef on;
-
+  CFStringRef fontName;
+  CFNumberRef fontSize;
+  CFNumberRef trans;
+  UInt32 i;
+  
   im = CFDictionaryGetValue(inUserInfo, CFSTR(kPrefIM));
 
 #if DEBUG_NOTIFY
@@ -878,15 +905,37 @@ NotificationCallback(CFNotificationCenterRef inCenter, void *inObserver,
               CFStringGetCStringPtr(im, kCFStringEncodingMacRoman));
 #endif
   
-  on = CFDictionaryGetValue(inUserInfo, CFSTR(kPrefCandVertical));
-  gCandVertical = on == kCFBooleanTrue ? true : false;
+  if ((on = CFDictionaryGetValue(inUserInfo, CFSTR(kPrefCandVertical))))
+    gCandVertical = on == kCFBooleanTrue ? true : false;
   
-  on = CFDictionaryGetValue(inUserInfo, CFSTR(kPrefModeTips));
-  gEnableModeTips = on == kCFBooleanTrue ? true : false;
+  // candidate font
+  if ((fontName = CFDictionaryGetValue(inUserInfo, CFSTR(kPrefCandFont)))) {
+    if (gCandFont)
+      CFRelease(gCandFont);
+    gCandFont = CFRetain(fontName);
+    if ((fontSize = CFDictionaryGetValue(inUserInfo, CFSTR(kPrefCandFontSize))))
+      CFNumberGetValue(fontSize, kCFNumberFloatType, &gCandFontSize);
+
+#if DEBUG_NOTIFY
+    DEBUG_PRINT("NotificationCallback() fontName=%s fontSize=%f\n",
+                CFStringGetCStringPtr(gCandFont, kCFStringEncodingMacRoman),
+                gCandFontSize);
+#endif
+  
+    for (i = 0; i < gNumSession; i++)
+      SetCandidateFont(gSessionList[i], gCandFont, gCandFontSize);
+  }
+    
+  if ((trans = CFDictionaryGetValue(inUserInfo, CFSTR(kPrefCandTransparency))))
+    CFNumberGetValue(trans, kCFNumberIntType, &gCandTransparency);
+  
+  if ((on = CFDictionaryGetValue(inUserInfo, CFSTR(kPrefModeTips))))
+    gEnableModeTips = on == kCFBooleanTrue ? true : false;
   
 #if DEBUG_NOTIFY
-  DEBUG_PRINT("NotificationCallback() vertical=%s modetips=%s\n",
+  DEBUG_PRINT("NotificationCallback() vertical=%s transparency=%s modetips=%s\n",
               gCandVertical ? "true" : "false",
+              gCandTransparency ? "true" : "false",
               gEnableModeTips ? "true" : "false");
 #endif
 
@@ -900,14 +949,10 @@ NotificationCallback(CFNotificationCenterRef inCenter, void *inObserver,
     CreateAllUIMContext(im);
 
 #ifdef SYNC_MODE
-    {
-      UInt32 i;
-
-      gMode = -1;
-      for (i = 0; i < gNumSession; i++) {
-        uim_prop_list_update((*gSessionList[i])->fUC);
-        uim_prop_label_update((*gSessionList[i])->fUC);
-      }
+    gMode = -1;
+    for (i = 0; i < gNumSession; i++) {
+      uim_prop_list_update((*gSessionList[i])->fUC);
+      uim_prop_label_update((*gSessionList[i])->fUC);
     }
 #else
     uim_prop_list_update((*gActiveSession)->fUC);
