@@ -1,6 +1,6 @@
 /* -*- mode:objc; coding:utf-8; tab-width:8; c-basic-offset:2; indent-tabs-mode:nil -*- */
 /*
-  Copyright (c) 2004 MacUIM Project
+  Copyright (c) 2003-2004 MacUIM contributors and others
   http://www.digital-genes.com/~yatsu/macuim/
 
   All rights reserved.
@@ -171,12 +171,16 @@ convertHelperString(char *str);
 - (void)renderFrame:(NSImage *)image
 {
   NSBezierPath *framePath;
-  NSColor *color;
+  NSColor *strokeColor, *fillColor;
 
-  if (clicked == NO)
-    color = [NSColor blackColor];
-  else
-    color = [NSColor whiteColor];
+  if (clicked == NO) {
+    strokeColor = [NSColor blackColor];
+    fillColor = [NSColor whiteColor];
+  }
+  else {
+    strokeColor = [NSColor blackColor];
+    fillColor = [NSColor blackColor];
+  }
 
   [image lockFocus];
 
@@ -184,32 +188,26 @@ convertHelperString(char *str);
     framePath =
       [NSBezierPath bezierPathWithRect:NSMakeRect(0.5, 3.5,
                                                   kMenuBarWidth - 1.0, kMenuBarHeight - 7.0)];
-    if (clicked == NO) {
-      [[NSColor whiteColor] set];
-      [framePath fill];
-    }
-    [color set];
+    [fillColor set];
+    [framePath fill];
+    [strokeColor set];
     [framePath stroke];
   }
   else {
     framePath =
       [NSBezierPath bezierPathWithRect:NSMakeRect(0.5, 3.5,
                                                   kMenuBarWidth2 - 1.0, kMenuBarHeight - 7.0)];
-    if (clicked == NO) {
-      [[NSColor whiteColor] set];
-      [framePath fill];
-    }
-    [color set];
+    [fillColor set];
+    [framePath fill];
+    [strokeColor set];
     [framePath stroke];
 
     framePath =
       [NSBezierPath bezierPathWithRect:NSMakeRect(kMenuBarWidth2 / 2.0, 3.5,
                                                   0.1, kMenuBarHeight - 7.0)];
-    if (clicked == NO) {
-      [[NSColor whiteColor] set];
-      [framePath fill];
-    }
-    [color set];
+    [fillColor set];
+    [framePath fill];
+    [strokeColor set];
     [framePath stroke];
   }
 
@@ -365,7 +363,7 @@ convertHelperString(char *str);
       CFMutableDictionaryRef dict;
       NSString *im;
       int j;
-      CFArrayRef array;
+      CFMutableArrayRef array;
 
       im = [imNames objectAtIndex:i];
       CFPreferencesSetAppValue(CFSTR(kPrefIM), im, CFSTR(kAppID));
