@@ -1,6 +1,6 @@
 /* -*- mode:objc; coding:utf-8; tab-width:8; c-basic-offset:2; indent-tabs-mode:nil -*- */
 /*
-  Copyright (c) 2004 MacUIM Project
+  Copyright (c) 2003-2004 MacUIM contributors and others
   http://www.digital-genes.com/~yatsu/macuim/
 
   All rights reserved.
@@ -66,6 +66,8 @@ typedef struct _IMModule {
   IBOutlet NSButton *modeTipsButton;
   IBOutlet NSButton *appletButton;
   IBOutlet NSTableView *imTable;
+  IBOutlet NSSlider *opacitySlider;
+  IBOutlet NSTextField *fontSample;
 
   CFStringRef appID;
 
@@ -75,6 +77,8 @@ typedef struct _IMModule {
   NSMutableArray *imOnArray;
   NSMutableArray *imNameArray;
   NSMutableArray *imScriptArray;
+  
+  NSFont *font;
 }
 
 - (IBAction)imChange:(id)sender;
@@ -89,6 +93,12 @@ typedef struct _IMModule {
 
 - (IBAction)modeTipsChange:(id)sender;
 
+- (IBAction)opacityChange:(id)sender;
+
+- (IBAction)chooseFont:(id)sender;
+
+- (void)setFont:(id)sender;
+
 - (void)prefSync;
 
 - (void)loadExtra;
@@ -103,6 +113,8 @@ typedef struct _IMModule {
 
 - (void)loadPrefs:(NSString *)im;
 
+- (void)updateFontSample;
+
 + (id)sharedPane;
 
 @end
