@@ -1,6 +1,6 @@
 /* -*- mode:objc; coding:utf-8; tab-width:8; c-basic-offset:2; indent-tabs-mode:nil -*- */
 /*
-  Copyright (c) 2004 MacUIM Project
+  Copyright (c) 2003-2004 MacUIM contributors and others
   http://www.digital-genes.com/~yatsu/macuim/
 
   All rights reserved.
@@ -151,6 +151,7 @@ prefChanged(CFNotificationCenterRef inCenter, void *inObserver,
 {
   CFPropertyListRef propVal;
   int i;
+  CFIndex ind;
   Boolean dummy;
   
   [imButton removeAllItems];
@@ -189,14 +190,46 @@ prefChanged(CFNotificationCenterRef inCenter, void *inObserver,
   if (propVal)
     CFRelease(propVal);
 
-  // display direction of candidate window
+  // display direction of candidate window (disabled)
+#if 0
   if (CFPreferencesGetAppBooleanValue(CFSTR(kPrefCandVertical), appID, &dummy))
     [listDirection selectCellAtRow:0 column:0];
   else
     [listDirection selectCellAtRow:0 column:1];
-
+#else
+  [listDirection selectCellAtRow:0 column:0];
+#endif
+  
   [listDirection setEnabled:false];
   
+  // candidate font
+  {
+    NSString *name = nil;
+    NSNumber *size = nil;
+    
+    propVal = CFPreferencesCopyAppValue(CFSTR(kPrefCandFont), appID);
+    if (propVal && CFGetTypeID(propVal) == CFStringGetTypeID())
+      name = (NSString *) propVal;
+    
+    propVal = CFPreferencesCopyAppValue(CFSTR(kPrefCandFontSize), appID);
+    if (propVal && CFGetTypeID(propVal) == CFNumberGetTypeID())
+      size = (NSNumber *) propVal;
+    
+    if (name && size)
+      font = [NSFont fontWithName:name size:[size floatValue]];
+    else
+      font = [NSFont userFontOfSize:12];
+    
+    [self updateFontSample];
+  }
+  
+  // transparency of candidate window
+  if ((ind = CFPreferencesGetAppIntegerValue(CFSTR(kPrefCandTransparency),
+                                             appID, &dummy)))
+    [opacitySlider setIntValue:ind];
+  else
+    [opacitySlider setIntValue:0];
+  
   // modetips flag
   if (CFPreferencesGetAppBooleanValue(CFSTR(kPrefModeTips), appID, &dummy))
     [modeTipsButton setState:NSOnState];
@@ -283,6 +316,31 @@ prefChanged(CFNotificationCenterRef inCenter, void *inObserver,
   [self prefSync];
 }
 
+- (IBAction)opacityChange:(id)sender
+{
+  [self prefSync];
+}
+
+- (IBAction)chooseFont:(id)sender
+{
+  [[NSFontManager sharedFontManager] orderFrontFontPanel:self];
+  [[NSFontManager sharedFontManager] setSelectedFont:font
+                                          isMultiple:NO];
+}
+
+- (void)setFont:(id)sender
+{
+  NSFont *newFont;
+  
+  newFont = [[NSFontManager sharedFontManager] convertFont:font];
+  [font release];
+  font = [newFont retain];
+  
+  [self updateFontSample];
+    
+  [self prefSync];
+}
+
 - (int)numberOfRowsInTableView:(NSTableView *)aTableView
 {
   return [imNameArray count];
@@ -323,6 +381,10 @@ prefChanged(CFNotificationCenterRef inCenter, void *inObserver,
 {
   CFNotificationCenterRef center;
   CFStringRef im;
+  int transVal;
+  CFNumberRef trans;
+  float fontSizeVal;
+  CFNumberRef fontSize;
   CFMutableArrayRef array;
   CFMutableDictionaryRef dict;
   int i;
@@ -346,13 +408,28 @@ prefChanged(CFNotificationCenterRef inCenter, void *inObserver,
     }
   }
 
-  // set display direction of candidate window
+  // set the display direction of candidate window (disabled)
+#if 0
   if ([listDirection selectedColumn] == 0)
     CFPreferencesSetAppValue(CFSTR(kPrefCandVertical), kCFBooleanTrue, appID);
   else
     CFPreferencesSetAppValue(CFSTR(kPrefCandVertical), kCFBooleanFalse, appID);
+#else
+  CFPreferencesSetAppValue(CFSTR(kPrefCandVertical), kCFBooleanTrue, appID);
+#endif
   
-  // set modetips flag
+  // set the transparency
+  transVal = [opacitySlider intValue];
+  trans = CFNumberCreate(kCFAllocatorDefault, kCFNumberIntType, &transVal);
+  CFPreferencesSetAppValue(CFSTR(kPrefCandTransparency), trans, appID);
+  
+  // candidate font
+  CFPreferencesSetAppValue(CFSTR(kPrefCandFont), [font fontName], appID);
+  fontSizeVal = [font pointSize];
+  fontSize = CFNumberCreate(kCFAllocatorDefault, kCFNumberFloatType, &fontSizeVal);
+  CFPreferencesSetAppValue(CFSTR(kPrefCandFontSize), fontSize, appID);
+  
+  // set the modetips flag
   if ([modeTipsButton state] == NSOffState)
     CFPreferencesSetAppValue(CFSTR(kPrefModeTips), kCFBooleanFalse, appID);
   else
@@ -373,14 +450,26 @@ prefChanged(CFNotificationCenterRef inCenter, void *inObserver,
   CFPreferencesAppSynchronize(appID);
 
   CFDictionarySetValue(dict, CFSTR(kPrefIM), im);
+  
+#if 0
   if ([listDirection selectedColumn] == 0)
     CFDictionarySetValue(dict, CFSTR(kPrefCandVertical), kCFBooleanTrue);
   else
     CFDictionarySetValue(dict, CFSTR(kPrefCandVertical), kCFBooleanFalse);
+#else
+  CFDictionarySetValue(dict, CFSTR(kPrefCandVertical), kCFBooleanTrue);
+#endif
+
+  CFDictionarySetValue(dict, CFSTR(kPrefCandTransparency), trans);
+  
+  CFDictionarySetValue(dict, CFSTR(kPrefCandFont), [font fontName]);
+  CFDictionarySetValue(dict, CFSTR(kPrefCandFontSize), fontSize);
+  
   if ([modeTipsButton state] == NSOnState)
     CFDictionarySetValue(dict, CFSTR(kPrefModeTips), kCFBooleanTrue);
   else
     CFDictionarySetValue(dict, CFSTR(kPrefModeTips), kCFBooleanFalse);
+  
   CFDictionarySetValue(dict, CFSTR(kPrefHelperIM), array);
   
   // post a notification that the preferences have changed
@@ -493,6 +582,34 @@ prefChanged(CFNotificationCenterRef inCenter, void *inObserver,
   }
 }
 
+- (void)updateFontSample
+{
+  NSRect fontFrame, boxFrame;
+  NSAttributedString *text;
+  NSString *fontName;
+  
+  fontName = [NSString stringWithFormat:@"%@ %d",
+              [font displayName], (int) [font pointSize]];
+
+  [fontSample setFont:font];
+  [fontSample setStringValue:fontName];
+
+  fontFrame = [fontSample frame];
+  boxFrame = [[fontSample superview] frame];
+    
+  text = [[[NSAttributedString alloc]
+           initWithString:fontName
+               attributes:[NSDictionary dictionaryWithObjectsAndKeys:
+                 font, NSFontAttributeName, nil]] autorelease];
+    
+  fontFrame.size.height = [text size].height + 4.0;
+  fontFrame.origin.y = (boxFrame.size.height - fontFrame.size.height) / 2.0;
+  [fontSample setFrameSize:fontFrame.size];
+  [fontSample setFrameOrigin:fontFrame.origin];
+  
+  [[fontSample superview] setNeedsDisplay:YES];
+}
+
 @end
 
 static void
